Module puzzles

Module puzzles 

Domain-specific puzzle modules.

Re-exports

pub use class::PuzzleClass;

Modules

class
The puzzle-family generator contract.
futoshiki
Futoshiki puzzle solver.
kenken
KenKen / Calcudoku: a Latin square whose cells partition into arithmetic cages, each carrying an operator (+ − × ÷) and a target its cells produce.
killer
Killer-Sudoku: a standard Sudoku whose cells partition into arithmetic cages.
sudoku
Sudoku puzzle creation, solving, generation, and symmetry transforms.
thermo
Thermo-Sudoku: a standard Sudoku plus thermometer clue furniture.