AC-3 worklist propagation using the adjacency graph.
Uses a bitset worklist for lower overhead than VecDeque + Vec<bool>.
AC-3 worklist propagation using the adjacency graph.
Uses a bitset worklist for lower overhead than VecDeque + Vec<bool>.