pub struct AllDifferentExcept<V: Clone + PartialEq + Debug> { /* private fields */ }Expand description
All-different over the scope, except that the configured sentinel
value may be assigned to any number of variables.
Non-sentinel assignments must remain pairwise distinct.
Implementations