pub struct SoftLambdaConstraint<D: Domain> { /* private fields */ }Expand description
A soft constraint backed by a closure, analogous to LambdaConstraint.
When the checker returns false, the constraint is “violated” and its
penalty is added to the objective during optimization search.
Implementations
Sourceimpl<D: Domain> SoftLambdaConstraint<D>
impl<D: Domain> SoftLambdaConstraint<D>
Sourceimpl<D: Domain> SoftLambdaConstraint<D>
impl<D: Domain> SoftLambdaConstraint<D>
Sourcepub fn is_satisfied(&self, assignment: &[Option<D::Value>]) -> bool
pub fn is_satisfied(&self, assignment: &[Option<D::Value>]) -> bool
Check whether the underlying predicate is satisfied.
This is separate from Constraint::check (which always returns true
so that soft constraints don’t prune) — use this to compute penalty costs.