select_variable

Function select_variable 

pub fn select_variable<D: Domain>(
    stack: &[VarId],
    variables: &[Variable<D>],
    ordering: Ordering,
    constraint_weights: &[f64],
    var_constraint_ids: &[Vec<usize>],
) -> Option<usize>
Select the next unassigned variable from the stack according to the ordering heuristic.

Returns the index into stack of the chosen variable, or None if empty.